local Barrel = LibStub("AceAddon-3.0"):GetAddon("Barrel")
local L = LibStub("AceLocale-3.0"):GetLocale("Barrel")
local ldb = LibStub("LibDataBroker-1.1")
local db_icon = LibStub("LibDBIcon-1.0")


local defaults = {
	profile = {
		ignoreLaunchers = false,
		ignoreNonLaunchers = false
	}
}

local options = {
	type = "group",
	name = "Barrel",
	childGroups = "tree",
	args = {
		Barrel = {
		type = "group",
		name = "Barrel",
		handler = Barrel,
			args = {
				ignoreLaunchers = {
					type = "toggle",
					name = L["Ignore Launchers"],
					get = function() return Barrel.db.profile.ignoreLaunchers end,
					set = function(info, value) 
						Barrel.db.profile.ignoreLaunchers = value
						Barrel:ToggleLaunchers()
					end,
				},
				ignoreNonLaunchers = {
					type = "toggle",
					name = L["Ignore non Launchers"],
					get = function() return Barrel.db.profile.ignoreNonLaunchers end,
					set = function(info, value) 
						Barrel.db.profile.ignoreNonLaunchers = value
						Barrel:ToggleNonLaunchers()
					end,
				},
			},
		},
	},
}

function Barrel:CreateMenu(name)
	local menuName = string.gsub(name, "FuBar(%s)\-(%s)", "")
	menuName = string.gsub(name, "%s", "")
	options.args.Barrel.args[menuName] = {
		type = "group",
		name = menuName,
		args = {
			[menuName] = {
				type = "group",
				name = menuName,
				order = 1,
				inline = true,
				args = {
					enable = {
						type = "toggle",
						name = L["Enable minimap icon"],
						width = "full",
						order = 1,
						get = function(info)
							local name = name
							return not self.db.profile[name].hide
						end,
						set = function(info, value)
							local name = name
							if ( value ) then
								self:EnableDataObject(name)
							else
								self:DisableDataObject(name)
							end
							self.db.profile[name].hide = not value
						end,
					},
					radius = {
						type = "range",
						name = L["Radius"],
						min = 0,
						max = 160,
						step = 1,
						order = 2,
						get = function() return self.db.profile[name].radius end,
						set = function(info, value)
							self.db.profile[name].radius = value
							db_icon:Refresh(name)
						end,
					},
					angle = {
						type = "range",
						name = L["Angle"],
						min = 0,
						max = 360,
						step = 1,
						order = 3,
						get = function() return self.db.profile[name].minimapPos end,
						set = function(info, value)
							self.db.profile[name].minimapPos = value
							db_icon:Refresh(name)
						end,
					},
				},
			},
		},
	}
end

function Barrel:Config()

	self.db = LibStub("AceDB-3.0"):New("BarrelDB", defaults, "Default")
	LibStub("AceConfig-3.0"):RegisterOptionsTable("Barrel", options)
	self.optionsname = LibStub("AceConfigDialog-3.0"):AddToBlizOptions("Barrel", "Barrel")
	options.args.profiles = LibStub("AceDBOptions-3.0"):GetOptionsTable(self.db)

end

